@@ -9,11 +9,14 @@ library(glue)
 library(dplyr)
 library(ggplot2)
 
-### creating a list column with `ggstatsplot` plots
+# for reproducibility
+set.seed(123)
+
+# creating a list column with `ggstatsplot` plots
 plots <- datasets::iris %>%
   dplyr::mutate(.data = ., Species2 = Species) %>% # just creates a copy of this variable
   dplyr::group_by(.data = ., Species) %>%                
-  tidyr::nest(data = .) %>%                        # creates a nested dataframe with list column called `data`
+  tidyr::nest(data = .) %>%                        # a nested dataframe with list column called `data`
   dplyr::mutate(                                   # creating a new list column of ggstatsplot outputs
     .data = .,
     plot = data %>%
@@ -23,7 +26,11 @@ plots <- datasets::iris %>%
           data = .,
           x = Sepal.Length,
           y = Sepal.Width,
-          messages = FALSE,                        # turns off all the warnings, notes, and reference messages   
+          xfill = "#0072B2",
+          yfill = "#009E73",
+          ggtheme = ggthemes::theme_fivethirtyeight(),
+          ggstatsplot.layer = FALSE,
+          messages = FALSE,                        # turns off warnings and notes messages   
           marginal.type = "boxplot",
           title =
             glue::glue("Species: {.$Species2} (n = {length(.$Sepal.Length)})")
@@ -31,16 +38,16 @@ plots <- datasets::iris %>%
       )
   )
 
-### display the new object (notice that the class of the `plot` list column is S3: gg)
+# display the new object (notice that the class of the `plot` list column is
+# S3: ggExtraPlot)
 plots
 
-### creating a grid with cowplot
+# creating a grid with cowplot
 ggstatsplot::combine_plots(
   plotlist = plots$plot,                           # list column containing all ggstatsplot objects
-  labels = c("(a)", "(b)", "(c)"),
   nrow = 3,
   ncol = 1,
-  title.text = "Relationship between sepal length and width for all Iris species",
+  title.text = "Relationship between sepal length and width for each Iris species",
   title.size = 14,
   caption.text = expression(
     paste(
@@ -52,98 +59,54 @@ ggstatsplot::combine_plots(
   )
 )
 
-## ----ggbetweenstats_purrr, message = FALSE, warning = FALSE, fig.height = 12, fig.width = 8----
-library(dplyr)
-library(glue)
-
-### creating a list column with `ggstatsplot` plots
-plots <- datasets::mtcars %>%
-  dplyr::mutate(.data = ., cyl2 = cyl) %>%        # just creates a copy of this variable
-  dplyr::group_by(.data = ., cyl) %>%             # 
-  tidyr::nest(data = .) %>%                       # creates a nested dataframe with list column called `data`
-  dplyr::mutate(                                  # creating a new list column of ggstatsplot outputs
-    .data = .,
-    plot = data %>%
-      purrr::map(
-        .x = .,
-        .f = ~ ggstatsplot::ggbetweenstats(
-          data = .,
-          x = am,
-          y = mpg,
-          plot.type = "box",                      # type of plot needed
-          messages = FALSE,                       # turns off all the warnings, notes, and reference messages
-          xlab = "Transmission",
-          ylab = "Miles/(US) gallon",
-          title = glue::glue(
-            "Number of cylinders: {.$cyl2}"       # this is where the duplicated cyl2 column is useful
-            ) 
-        )
-      )
-  )
-
-### display the new object (notice that the class of the `plot` list column is S3: gg)
-plots
-
-### creating a grid with cowplot
-ggstatsplot::combine_plots(
-  plotlist = plots$plot,       # list column containing all ggstatsplot objects
-  nrow = 3,
-  ncol = 1,
-  labels = c("(a)","(b)","(c)"),
-  title.text = "MPG and car transmission relationship (for each cylinder count)",
-  title.size = 13,
-  title.color = "blue",
-  caption.text = expression(
-    paste(
-      italic("Transmission"),
-      ": 0 = automatic, 1 = manual",
-      sep = ""
-    ),
-    caption.size = 10,
-    caption.color = "red"
-  )
-)
-
-## ----ggbetweenstats_plyr1, message = FALSE, warning = FALSE, fig.height = 12, fig.width = 8----
+## ----ggscatterstats_plyr, message = FALSE, warning = FALSE, fig.height = 12, fig.width = 12----
 library(plyr)
-library(ggstatsplot)
+library(gapminder)
 
 # for reproducibility
 set.seed(123)
 
 # let's have a look at the structure of the data
-dplyr::glimpse(x = ggstatsplot::movies_long)
+dplyr::glimpse(x = gapminder::gapminder)
 
 # creating a list of plots
 plots <- plyr::dlply(
-  .data = ggstatsplot::movies_long,
-  .variables = .(genre),
+  .data = dplyr::filter(gapminder::gapminder, 
+                        year == 2007, continent != "Oceania"),
+  .variables = .(continent),
   .fun = function(data)
-    ggstatsplot::ggpiestats(
+    ggstatsplot::ggscatterstats(
       data = data,
-      main = mpaa,
-      title = glue::glue("Genre: {data$genre}")
-    )
+      x = gdpPercap,
+      y = lifeExp,
+      xfill = "#0072B2",
+      yfill = "#009E73",
+      label.var = "country",
+      label.expression = "lifeExp < 45",
+      title = glue::glue("Continent: {data$continent}"),
+      marginal = FALSE
+    ) +
+    ggplot2::scale_x_continuous(labels = scales::comma)
 )
 
 # combining individual plots
-ggstatsplot::combine_plots(plotlist = plots, 
-                           title.text = "Differences in MPAA ratings by movie genre",
-                           title.color = "darkgreen",
-                           caption.text = "MPAA: Motion Picture Association of America",
-                           caption.color = "orange",
-                           nrow = 3,
-                           ncol = 2)
+ggstatsplot::combine_plots(
+  plotlist = plots,
+  title.text = "Relationship between GDP (per capita) and life expectancy",
+  nrow = 2,
+  ncol = 2
+)
 
 ## ----ggbetweenstats_subtext, message = FALSE, warning = FALSE, fig.height = 8, fig.width = 8----
 library(ggstatsplot)
 
 ggstatsplot::combine_plots(
   # preparing the plot with ggstatsplot function
+  # let's use only 20% of data to speed up the process
   ggstatsplot::ggcoefstats(
     x = stats::lm(
       formula = rating ~ stats::poly(budget, degree = 3),
-      data = ggstatsplot::movies_long,
+      data = dplyr::sample_frac(tbl = ggstatsplot::movies_long, size = 0.2),
       na.action = na.omit
     ),
     exclude.intercept = FALSE,
@@ -175,3 +138,7 @@ ggstatsplot::combine_plots(
   sub.size = 12
 )
 
+## ----session_info, eval = TRUE------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+options(width = 200)
+devtools::session_info()
+
